@@ -24,7 +24,7 @@
 
 /* List head of all registered protocols */
 static struct list protocols = LIST_HEAD_INIT(protocols);
-struct protocol *__protocol_by_family[AF_CUST_MAX][2][2] = { };
+struct protocol *__protocol_by_family[AF_CUST_MAX][2][2] __read_mostly = { };
 
 /* This is the global spinlock we may need to register/unregister listeners or
  * protocols. Its main purpose is in fact to serialize the rare stop/deinit()
@@ -36,9 +36,9 @@ __decl_spinlock(proto_lock);
 void protocol_register(struct protocol *proto)
 {
 	HA_SPIN_LOCK(PROTO_LOCK, &proto_lock);
-	LIST_ADDQ(&protocols, &proto->list);
-	if (proto->sock_domain >= 0 && proto->sock_domain < AF_CUST_MAX)
-		__protocol_by_family[proto->sock_domain]
+	LIST_APPEND(&protocols, &proto->list);
+	if (proto->fam->sock_domain >= 0 && proto->fam->sock_domain < AF_CUST_MAX)
+		__protocol_by_family[proto->fam->sock_domain]
 			[proto->sock_type == SOCK_DGRAM]
 			[proto->ctrl_type == SOCK_DGRAM] = proto;
 	HA_SPIN_UNLOCK(PROTO_LOCK, &proto_lock);
@@ -50,7 +50,7 @@ void protocol_register(struct protocol *proto)
 void protocol_unregister(struct protocol *proto)
 {
 	HA_SPIN_LOCK(PROTO_LOCK, &proto_lock);
-	LIST_DEL(&proto->list);
+	LIST_DELETE(&proto->list);
 	LIST_INIT(&proto->list);
 	HA_SPIN_UNLOCK(PROTO_LOCK, &proto_lock);
 }
@@ -86,7 +86,7 @@ int protocol_bind_all(int verbose)
 				else if (lerr & ERR_WARN)
 					ha_warning("Starting %s %s: %s\n",
 						   proxy_type_str(px), px->id, errmsg);
-				free(errmsg); errmsg = NULL;
+				ha_free(&errmsg);
 			}
 			if (lerr & ERR_ABORT)
 				break;
@@ -155,7 +155,7 @@ void protocol_stop_now(void)
 	list_for_each_entry(proto, &protocols, list) {
 		list_for_each_entry_safe(listener, lback, &proto->receivers, rx.proto_list)
 			if (!listener->bind_conf->frontend->grace)
-				stop_listener(listener, 0, 1, 0);
+				stop_listener(listener, 0, 1);
 	}
 	HA_SPIN_UNLOCK(PROTO_LOCK, &proto_lock);
 }
@@ -175,7 +175,7 @@ int protocol_pause_all(void)
 	HA_SPIN_LOCK(PROTO_LOCK, &proto_lock);
 	list_for_each_entry(proto, &protocols, list) {
 		list_for_each_entry(listener, &proto->receivers, rx.proto_list)
-			if (!pause_listener(listener))
+			if (!pause_listener(listener, 0))
 				err |= ERR_FATAL;
 	}
 	HA_SPIN_UNLOCK(PROTO_LOCK, &proto_lock);
@@ -197,7 +197,7 @@ int protocol_resume_all(void)
 	HA_SPIN_LOCK(PROTO_LOCK, &proto_lock);
 	list_for_each_entry(proto, &protocols, list) {
 		list_for_each_entry(listener, &proto->receivers, rx.proto_list)
-			if (!resume_listener(listener))
+			if (!resume_listener(listener, 0))
 				err |= ERR_FATAL;
 	}
 	HA_SPIN_UNLOCK(PROTO_LOCK, &proto_lock);
